summaryrefslogtreecommitdiff
path: root/gdb
diff options
context:
space:
mode:
authorAndrew Cagney <cagney@redhat.com>2004-07-20 19:45:07 +0000
committerAndrew Cagney <cagney@redhat.com>2004-07-20 19:45:07 +0000
commit91a2a48d3a977bd94f5fe966f31c14bfdcaadb59 (patch)
tree4f39f4824410fad913ab8f9aaa88257b245674d0 /gdb
parent065c4ff4bde56f1aeff9b6595003b30c4a31b0cd (diff)
downloadgdb-91a2a48d3a977bd94f5fe966f31c14bfdcaadb59.tar.gz
2004-07-20 Andrew Cagney <cagney@gnu.org>
* breakpoint.c (deprecated_read_memory_nobpt): Rename read_memory_nobpt. * sparc-linux-tdep.c (sparc_linux_sigtramp_start): Update. * s390-tdep.c (s390_readinstruction, s390_in_function_epilogue_p) (s390_sigtramp_frame_sniffer): Update. * mn10300-tdep.c (mn10300_analyze_prologue): Update. * mipsnbsd-tdep.c (mipsnbsd_sigtramp_offset): Update. * mips-tdep.c (mips_fetch_instruction, mips16_fetch_instruction) (mips32_fetch_instruction): Update. * mcore-tdep.c (get_insn): Update. * m68klinux-tdep.c (m68k_linux_pc_in_sigtramp): Update. * i386nbsd-tdep.c (i386nbsd_sigtramp_offset): Update. * i386ly-tdep.c (i386lynx_saved_pc_after_call): Update. * i386-linux-tdep.c (i386_linux_sigtramp_start) (i386_linux_rt_sigtramp_start): Update. * i386-linux-nat.c (child_resume): Update. * hppa-tdep.c (skip_prologue_hard_way, hppa_frame_cache): Update. * hppa-linux-tdep.c (insns_match_pattern): Update. * gdbcore.h: Update. * frv-tdep.c (frv_gdbarch_adjust_breakpoint_address): Update. * frame.c (safe_frame_unwind_memory): Update. * amd64-linux-tdep.c (amd64_linux_sigtramp_start): Update. * alphanbsd-tdep.c (alphanbsd_sigtramp_offset): Update. * alpha-tdep.c (alpha_read_insn): Update.
Diffstat (limited to 'gdb')
-rw-r--r--gdb/ChangeLog27
-rw-r--r--gdb/alpha-tdep.c2
-rw-r--r--gdb/alphanbsd-tdep.c4
-rw-r--r--gdb/amd64-linux-tdep.c4
-rw-r--r--gdb/breakpoint.c6
-rw-r--r--gdb/frame.c4
-rw-r--r--gdb/frv-tdep.c2
-rw-r--r--gdb/gdbcore.h7
-rw-r--r--gdb/hppa-linux-tdep.c2
-rw-r--r--gdb/hppa-tdep.c12
-rw-r--r--gdb/i386-linux-nat.c2
-rw-r--r--gdb/i386-linux-tdep.c8
-rw-r--r--gdb/i386ly-tdep.c2
-rw-r--r--gdb/i386nbsd-tdep.c6
-rw-r--r--gdb/m68klinux-tdep.c2
-rw-r--r--gdb/mcore-tdep.c2
-rw-r--r--gdb/mips-tdep.c6
-rw-r--r--gdb/mipsnbsd-tdep.c4
-rw-r--r--gdb/mn10300-tdep.c14
-rw-r--r--gdb/s390-tdep.c12
-rw-r--r--gdb/sparc-linux-tdep.c4
21 files changed, 82 insertions, 50 deletions
diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index caea941f804..cd0767d7c43 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,5 +1,32 @@
2004-07-20 Andrew Cagney <cagney@gnu.org>
+ * breakpoint.c (deprecated_read_memory_nobpt): Rename
+ read_memory_nobpt.
+ * sparc-linux-tdep.c (sparc_linux_sigtramp_start): Update.
+ * s390-tdep.c (s390_readinstruction, s390_in_function_epilogue_p)
+ (s390_sigtramp_frame_sniffer): Update.
+ * mn10300-tdep.c (mn10300_analyze_prologue): Update.
+ * mipsnbsd-tdep.c (mipsnbsd_sigtramp_offset): Update.
+ * mips-tdep.c (mips_fetch_instruction, mips16_fetch_instruction)
+ (mips32_fetch_instruction): Update.
+ * mcore-tdep.c (get_insn): Update.
+ * m68klinux-tdep.c (m68k_linux_pc_in_sigtramp): Update.
+ * i386nbsd-tdep.c (i386nbsd_sigtramp_offset): Update.
+ * i386ly-tdep.c (i386lynx_saved_pc_after_call): Update.
+ * i386-linux-tdep.c (i386_linux_sigtramp_start)
+ (i386_linux_rt_sigtramp_start): Update.
+ * i386-linux-nat.c (child_resume): Update.
+ * hppa-tdep.c (skip_prologue_hard_way, hppa_frame_cache): Update.
+ * hppa-linux-tdep.c (insns_match_pattern): Update.
+ * gdbcore.h: Update.
+ * frv-tdep.c (frv_gdbarch_adjust_breakpoint_address): Update.
+ * frame.c (safe_frame_unwind_memory): Update.
+ * amd64-linux-tdep.c (amd64_linux_sigtramp_start): Update.
+ * alphanbsd-tdep.c (alphanbsd_sigtramp_offset): Update.
+ * alpha-tdep.c (alpha_read_insn): Update.
+
+2004-07-20 Andrew Cagney <cagney@gnu.org>
+
* tramp-frame.h (struct tramp_frame): Change "insn" to a struct
containing both bytes and mask. Add "frame_type".
* tramp-frame.c (tramp_frame_start): Update.
diff --git a/gdb/alpha-tdep.c b/gdb/alpha-tdep.c
index 08c9e4a069e..74f881d5edf 100644
--- a/gdb/alpha-tdep.c
+++ b/gdb/alpha-tdep.c
@@ -628,7 +628,7 @@ alpha_read_insn (CORE_ADDR pc)
char buf[4];
int status;
- status = read_memory_nobpt (pc, buf, 4);
+ status = deprecated_read_memory_nobpt (pc, buf, 4);
if (status)
memory_error (status, pc);
return extract_unsigned_integer (buf, 4);
diff --git a/gdb/alphanbsd-tdep.c b/gdb/alphanbsd-tdep.c
index 97d32ec305b..84c89c8de84 100644
--- a/gdb/alphanbsd-tdep.c
+++ b/gdb/alphanbsd-tdep.c
@@ -155,7 +155,7 @@ alphanbsd_sigtramp_offset (CORE_ADDR pc)
LONGEST off;
int i;
- if (read_memory_nobpt (pc, (char *) w, 4) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) w, 4) != 0)
return -1;
for (i = 0; i < RETCODE_NWORDS; i++)
@@ -169,7 +169,7 @@ alphanbsd_sigtramp_offset (CORE_ADDR pc)
off = i * 4;
pc -= off;
- if (read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
return -1;
if (memcmp (ret, sigtramp_retcode, RETCODE_SIZE) == 0)
diff --git a/gdb/amd64-linux-tdep.c b/gdb/amd64-linux-tdep.c
index 8365ed3ea07..d8d77a4ee47 100644
--- a/gdb/amd64-linux-tdep.c
+++ b/gdb/amd64-linux-tdep.c
@@ -97,7 +97,7 @@ amd64_linux_sigtramp_start (CORE_ADDR pc)
PC is not at the start of the instruction sequence, there will be
a few trailing readable bytes on the stack. */
- if (read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
return 0;
if (buf[0] != LINUX_SIGTRAMP_INSN0)
@@ -107,7 +107,7 @@ amd64_linux_sigtramp_start (CORE_ADDR pc)
pc -= LINUX_SIGTRAMP_OFFSET1;
- if (read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
return 0;
}
diff --git a/gdb/breakpoint.c b/gdb/breakpoint.c
index 018f4646531..94665bcb46a 100644
--- a/gdb/breakpoint.c
+++ b/gdb/breakpoint.c
@@ -627,7 +627,7 @@ commands_command (char *arg, int from_tty)
shadow contents, not the breakpoints themselves. From breakpoint.c. */
int
-read_memory_nobpt (CORE_ADDR memaddr, char *myaddr, unsigned len)
+deprecated_read_memory_nobpt (CORE_ADDR memaddr, char *myaddr, unsigned len)
{
int status;
struct bp_location *b;
@@ -695,7 +695,7 @@ read_memory_nobpt (CORE_ADDR memaddr, char *myaddr, unsigned len)
if (bp_addr > memaddr)
{
/* Copy the section of memory before the breakpoint. */
- status = read_memory_nobpt (memaddr, myaddr, bp_addr - memaddr);
+ status = deprecated_read_memory_nobpt (memaddr, myaddr, bp_addr - memaddr);
if (status != 0)
return status;
}
@@ -703,7 +703,7 @@ read_memory_nobpt (CORE_ADDR memaddr, char *myaddr, unsigned len)
if (bp_addr + bp_size < memaddr + len)
{
/* Copy the section of memory after the breakpoint. */
- status = read_memory_nobpt (bp_addr + bp_size,
+ status = deprecated_read_memory_nobpt (bp_addr + bp_size,
myaddr + bp_addr + bp_size - memaddr,
memaddr + len - (bp_addr + bp_size));
if (status != 0)
diff --git a/gdb/frv-tdep.c b/gdb/frv-tdep.c
index 9b7524c2bb0..2f6679736c6 100644
--- a/gdb/frv-tdep.c
+++ b/gdb/frv-tdep.c
@@ -456,7 +456,7 @@ frv_gdbarch_adjust_breakpoint_address (struct gdbarch *gdbarch, CORE_ADDR bpaddr
char instr[frv_instr_size];
int status;
- status = read_memory_nobpt (addr, instr, sizeof instr);
+ status = deprecated_read_memory_nobpt (addr, instr, sizeof instr);
if (status != 0)
break;
diff --git a/gdb/gdbcore.h b/gdb/gdbcore.h
index 2c8427c8c63..734e7dfc760 100644
--- a/gdb/gdbcore.h
+++ b/gdb/gdbcore.h
@@ -45,7 +45,12 @@ extern int have_core_file_p (void);
address out of bounds. If breakpoints are inserted, returns shadow
contents, not the breakpoints themselves. From breakpoint.c. */
-extern int read_memory_nobpt (CORE_ADDR memaddr, char *myaddr, unsigned len);
+/* NOTE: cagney/2004-06-10: Code reading from a live inferior can use
+ the get_frame_memory methods, code reading from an exec can use the
+ target methods. */
+
+extern int deprecated_read_memory_nobpt (CORE_ADDR memaddr, char *myaddr,
+ unsigned len);
/* Report a memory error with error(). */
diff --git a/gdb/hppa-linux-tdep.c b/gdb/hppa-linux-tdep.c
index 6b3c0146426..7f32236274d 100644
--- a/gdb/hppa-linux-tdep.c
+++ b/gdb/hppa-linux-tdep.c
@@ -151,7 +151,7 @@ insns_match_pattern (CORE_ADDR pc,
{
char buf[4];
- read_memory_nobpt (npc, buf, 4);
+ deprecated_read_memory_nobpt (npc, buf, 4);
insn[i] = extract_unsigned_integer (buf, 4);
if ((insn[i] & pattern[i].mask) == pattern[i].data)
npc += 4;
diff --git a/gdb/hppa-tdep.c b/gdb/hppa-tdep.c
index 7861fc349ed..221f73984ce 100644
--- a/gdb/hppa-tdep.c
+++ b/gdb/hppa-tdep.c
@@ -1327,7 +1327,7 @@ restart:
old_save_sp = save_sp;
old_stack_remaining = stack_remaining;
- status = read_memory_nobpt (pc, buf, 4);
+ status = deprecated_read_memory_nobpt (pc, buf, 4);
inst = extract_unsigned_integer (buf, 4);
/* Yow! */
@@ -1376,7 +1376,7 @@ restart:
while (reg_num >= (TARGET_PTR_BIT == 64 ? 19 : 23) && reg_num <= 26)
{
pc += 4;
- status = read_memory_nobpt (pc, buf, 4);
+ status = deprecated_read_memory_nobpt (pc, buf, 4);
inst = extract_unsigned_integer (buf, 4);
if (status != 0)
return pc;
@@ -1389,7 +1389,7 @@ restart:
reg_num = inst_saves_fr (inst);
save_fr &= ~(1 << reg_num);
- status = read_memory_nobpt (pc + 4, buf, 4);
+ status = deprecated_read_memory_nobpt (pc + 4, buf, 4);
next_inst = extract_unsigned_integer (buf, 4);
/* Yow! */
@@ -1416,13 +1416,13 @@ restart:
while (reg_num >= 4 && reg_num <= (TARGET_PTR_BIT == 64 ? 11 : 7))
{
pc += 8;
- status = read_memory_nobpt (pc, buf, 4);
+ status = deprecated_read_memory_nobpt (pc, buf, 4);
inst = extract_unsigned_integer (buf, 4);
if (status != 0)
return pc;
if ((inst & 0xfc000000) != 0x34000000)
break;
- status = read_memory_nobpt (pc + 4, buf, 4);
+ status = deprecated_read_memory_nobpt (pc + 4, buf, 4);
next_inst = extract_unsigned_integer (buf, 4);
if (status != 0)
return pc;
@@ -1647,7 +1647,7 @@ hppa_frame_cache (struct frame_info *next_frame, void **this_cache)
{
int reg;
char buf4[4];
- long status = read_memory_nobpt (pc, buf4, sizeof buf4);
+ long status = deprecated_read_memory_nobpt (pc, buf4, sizeof buf4);
long inst = extract_unsigned_integer (buf4, sizeof buf4);
/* Note the interesting effects of this instruction. */
diff --git a/gdb/i386-linux-nat.c b/gdb/i386-linux-nat.c
index 061f645c8cf..38558f11524 100644
--- a/gdb/i386-linux-nat.c
+++ b/gdb/i386-linux-nat.c
@@ -815,7 +815,7 @@ child_resume (ptid_t ptid, int step, enum target_signal signal)
that's about to be restored, and set the trace flag there. */
/* First check if PC is at a system call. */
- if (read_memory_nobpt (pc, (char *) buf, LINUX_SYSCALL_LEN) == 0
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_SYSCALL_LEN) == 0
&& memcmp (buf, linux_syscall, LINUX_SYSCALL_LEN) == 0)
{
int syscall = read_register_pid (LINUX_SYSCALL_REGNUM,
diff --git a/gdb/i386-linux-tdep.c b/gdb/i386-linux-tdep.c
index 2b08e895fef..2733b5f4df5 100644
--- a/gdb/i386-linux-tdep.c
+++ b/gdb/i386-linux-tdep.c
@@ -130,7 +130,7 @@ i386_linux_sigtramp_start (CORE_ADDR pc)
PC is not at the start of the instruction sequence, there will be
a few trailing readable bytes on the stack. */
- if (read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
return 0;
if (buf[0] != LINUX_SIGTRAMP_INSN0)
@@ -151,7 +151,7 @@ i386_linux_sigtramp_start (CORE_ADDR pc)
pc -= adjust;
- if (read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_SIGTRAMP_LEN) != 0)
return 0;
}
@@ -197,7 +197,7 @@ i386_linux_rt_sigtramp_start (CORE_ADDR pc)
PC is not at the start of the instruction sequence, there will be
a few trailing readable bytes on the stack. */
- if (read_memory_nobpt (pc, (char *) buf, LINUX_RT_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_RT_SIGTRAMP_LEN) != 0)
return 0;
if (buf[0] != LINUX_RT_SIGTRAMP_INSN0)
@@ -207,7 +207,7 @@ i386_linux_rt_sigtramp_start (CORE_ADDR pc)
pc -= LINUX_RT_SIGTRAMP_OFFSET1;
- if (read_memory_nobpt (pc, (char *) buf, LINUX_RT_SIGTRAMP_LEN) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) buf, LINUX_RT_SIGTRAMP_LEN) != 0)
return 0;
}
diff --git a/gdb/i386ly-tdep.c b/gdb/i386ly-tdep.c
index 2374b71aa1f..d749dc4e552 100644
--- a/gdb/i386ly-tdep.c
+++ b/gdb/i386ly-tdep.c
@@ -41,7 +41,7 @@ i386lynx_saved_pc_after_call (struct frame_info *frame)
static const unsigned char call_inst[] =
{ 0x9a, 0, 0, 0, 0, 8, 0 }; /* lcall 0x8,0x0 */
- read_memory_nobpt (frame->pc - 7, opcode, 7);
+ deprecated_read_memory_nobpt (frame->pc - 7, opcode, 7);
if (memcmp (opcode, call_inst, 7) == 0)
return read_memory_unsigned_integer (read_register (SP_REGNUM) + 4, 4);
diff --git a/gdb/i386nbsd-tdep.c b/gdb/i386nbsd-tdep.c
index 3f19608788f..212127355cf 100644
--- a/gdb/i386nbsd-tdep.c
+++ b/gdb/i386nbsd-tdep.c
@@ -138,7 +138,7 @@ i386nbsd_sigtramp_offset (CORE_ADDR pc)
LONGEST off;
int i;
- if (read_memory_nobpt (pc, &insn, 1) != 0)
+ if (deprecated_read_memory_nobpt (pc, &insn, 1) != 0)
return -1;
switch (insn)
@@ -150,7 +150,7 @@ i386nbsd_sigtramp_offset (CORE_ADDR pc)
case RETCODE_INSN2:
/* INSN2 and INSN3 are the same. Read at the location of PC+1
to determine if we're actually looking at INSN2 or INSN3. */
- if (read_memory_nobpt (pc + 1, &insn, 1) != 0)
+ if (deprecated_read_memory_nobpt (pc + 1, &insn, 1) != 0)
return -1;
if (insn == RETCODE_INSN3)
@@ -173,7 +173,7 @@ i386nbsd_sigtramp_offset (CORE_ADDR pc)
pc -= off;
- if (read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
return -1;
if (memcmp (ret, sigtramp_retcode, sizeof (ret)) == 0)
diff --git a/gdb/m68klinux-tdep.c b/gdb/m68klinux-tdep.c
index 0b84483fb59..e385dbad627 100644
--- a/gdb/m68klinux-tdep.c
+++ b/gdb/m68klinux-tdep.c
@@ -66,7 +66,7 @@ m68k_linux_pc_in_sigtramp (CORE_ADDR pc, char *name)
char buf[12];
unsigned long insn0, insn1, insn2;
- if (read_memory_nobpt (pc - 4, buf, sizeof (buf)))
+ if (deprecated_read_memory_nobpt (pc - 4, buf, sizeof (buf)))
return 0;
insn1 = extract_unsigned_integer (buf + 4, 4);
insn2 = extract_unsigned_integer (buf + 8, 4);
diff --git a/gdb/mcore-tdep.c b/gdb/mcore-tdep.c
index f8f7b8e0783..d73b3cfe3f5 100644
--- a/gdb/mcore-tdep.c
+++ b/gdb/mcore-tdep.c
@@ -1008,7 +1008,7 @@ static int
get_insn (CORE_ADDR pc)
{
char buf[4];
- int status = read_memory_nobpt (pc, buf, 2);
+ int status = deprecated_read_memory_nobpt (pc, buf, 2);
if (status != 0)
return 0;
diff --git a/gdb/mips-tdep.c b/gdb/mips-tdep.c
index a98dd3c7d63..b797e395e3a 100644
--- a/gdb/mips-tdep.c
+++ b/gdb/mips-tdep.c
@@ -973,7 +973,7 @@ mips_fetch_instruction (CORE_ADDR addr)
}
else
instlen = MIPS_INSTLEN;
- status = read_memory_nobpt (addr, buf, instlen);
+ status = deprecated_read_memory_nobpt (addr, buf, instlen);
if (status)
memory_error (status, addr);
return extract_unsigned_integer (buf, instlen);
@@ -988,7 +988,7 @@ mips16_fetch_instruction (CORE_ADDR addr)
instlen = MIPS16_INSTLEN;
addr = unmake_mips16_addr (addr);
- status = read_memory_nobpt (addr, buf, instlen);
+ status = deprecated_read_memory_nobpt (addr, buf, instlen);
if (status)
memory_error (status, addr);
return extract_unsigned_integer (buf, instlen);
@@ -1001,7 +1001,7 @@ mips32_fetch_instruction (CORE_ADDR addr)
int instlen;
int status;
instlen = MIPS_INSTLEN;
- status = read_memory_nobpt (addr, buf, instlen);
+ status = deprecated_read_memory_nobpt (addr, buf, instlen);
if (status)
memory_error (status, addr);
return extract_unsigned_integer (buf, instlen);
diff --git a/gdb/mipsnbsd-tdep.c b/gdb/mipsnbsd-tdep.c
index 163d5ff0c06..e4dd65a75b4 100644
--- a/gdb/mipsnbsd-tdep.c
+++ b/gdb/mipsnbsd-tdep.c
@@ -198,7 +198,7 @@ mipsnbsd_sigtramp_offset (CORE_ADDR pc)
LONGEST off;
int i;
- if (read_memory_nobpt (pc, (char *) w, sizeof (w)) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) w, sizeof (w)) != 0)
return -1;
for (i = 0; i < RETCODE_NWORDS; i++)
@@ -212,7 +212,7 @@ mipsnbsd_sigtramp_offset (CORE_ADDR pc)
off = i * 4;
pc -= off;
- if (read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
+ if (deprecated_read_memory_nobpt (pc, (char *) ret, sizeof (ret)) != 0)
return -1;
if (memcmp (ret, retcode, RETCODE_SIZE) == 0)
diff --git a/gdb/mn10300-tdep.c b/gdb/mn10300-tdep.c
index e5e9dd27481..dce5cb3a8bd 100644
--- a/gdb/mn10300-tdep.c
+++ b/gdb/mn10300-tdep.c
@@ -557,7 +557,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
/* Get the next two bytes into buf, we need two because rets is a two
byte insn and the first isn't enough to uniquely identify it. */
- status = read_memory_nobpt (pc, buf, 2);
+ status = deprecated_read_memory_nobpt (pc, buf, 2);
if (status != 0)
return pc;
@@ -597,7 +597,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
/* Suck in two bytes. */
if (addr + 2 >= stop
- || (status = read_memory_nobpt (addr, buf, 2)) != 0)
+ || (status = deprecated_read_memory_nobpt (addr, buf, 2)) != 0)
{
fix_frame_pointer (fi, 0);
return addr;
@@ -621,7 +621,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
if (buf[0] == 0xcf)
{
/* Extract the register list for the movm instruction. */
- status = read_memory_nobpt (addr + 1, buf, 1);
+ status = deprecated_read_memory_nobpt (addr + 1, buf, 1);
movm_args = *buf;
addr += 2;
@@ -639,7 +639,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
}
/* Get the next two bytes so the prologue scan can continue. */
- status = read_memory_nobpt (addr, buf, 2);
+ status = deprecated_read_memory_nobpt (addr, buf, 2);
if (status != 0)
{
/* Fix fi->frame since it's bogus at this point. */
@@ -676,7 +676,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
}
/* Get two more bytes so scanning can continue. */
- status = read_memory_nobpt (addr, buf, 2);
+ status = deprecated_read_memory_nobpt (addr, buf, 2);
if (status != 0)
{
/* Fix fi->frame if it's bogus at this point. */
@@ -698,7 +698,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
If none of the above was found, then this prologue has no
additional stack. */
- status = read_memory_nobpt (addr, buf, 2);
+ status = deprecated_read_memory_nobpt (addr, buf, 2);
if (status != 0)
{
/* Fix fi->frame if it's bogus at this point. */
@@ -721,7 +721,7 @@ mn10300_analyze_prologue (struct frame_info *fi, CORE_ADDR pc)
{
/* Suck in imm_size more bytes, they'll hold the size of the
current frame. */
- status = read_memory_nobpt (addr + 2, buf, imm_size);
+ status = deprecated_read_memory_nobpt (addr + 2, buf, imm_size);
if (status != 0)
{
/* Fix fi->frame if it's bogus at this point. */
diff --git a/gdb/s390-tdep.c b/gdb/s390-tdep.c
index fbaf56709d1..57c8c6b5419 100644
--- a/gdb/s390-tdep.c
+++ b/gdb/s390-tdep.c
@@ -922,12 +922,12 @@ s390_readinstruction (bfd_byte instr[], CORE_ADDR at)
static int s390_instrlen[] = { 2, 4, 4, 6 };
int instrlen;
- if (read_memory_nobpt (at, &instr[0], 2))
+ if (deprecated_read_memory_nobpt (at, &instr[0], 2))
return -1;
instrlen = s390_instrlen[instr[0] >> 6];
if (instrlen > 2)
{
- if (read_memory_nobpt (at + 2, &instr[2], instrlen - 2))
+ if (deprecated_read_memory_nobpt (at + 2, &instr[2], instrlen - 2))
return -1;
}
return instrlen;
@@ -1724,19 +1724,19 @@ s390_in_function_epilogue_p (struct gdbarch *gdbarch, CORE_ADDR pc)
int d2;
if (word_size == 4
- && !read_memory_nobpt (pc - 4, insn, 4)
+ && !deprecated_read_memory_nobpt (pc - 4, insn, 4)
&& is_rs (insn, op_lm, &r1, &r3, &d2, &b2)
&& r3 == S390_SP_REGNUM - S390_R0_REGNUM)
return 1;
if (word_size == 4
- && !read_memory_nobpt (pc - 6, insn, 6)
+ && !deprecated_read_memory_nobpt (pc - 6, insn, 6)
&& is_rsy (insn, op1_lmy, op2_lmy, &r1, &r3, &d2, &b2)
&& r3 == S390_SP_REGNUM - S390_R0_REGNUM)
return 1;
if (word_size == 8
- && !read_memory_nobpt (pc - 6, insn, 6)
+ && !deprecated_read_memory_nobpt (pc - 6, insn, 6)
&& is_rsy (insn, op1_lmg, op2_lmg, &r1, &r3, &d2, &b2)
&& r3 == S390_SP_REGNUM - S390_R0_REGNUM)
return 1;
@@ -2251,7 +2251,7 @@ s390_sigtramp_frame_sniffer (struct frame_info *next_frame)
CORE_ADDR pc = frame_pc_unwind (next_frame);
bfd_byte sigreturn[2];
- if (read_memory_nobpt (pc, sigreturn, 2))
+ if (deprecated_read_memory_nobpt (pc, sigreturn, 2))
return NULL;
if (sigreturn[0] != 0x0a /* svc */)
diff --git a/gdb/sparc-linux-tdep.c b/gdb/sparc-linux-tdep.c
index 2484a5332e1..48e0a0d205f 100644
--- a/gdb/sparc-linux-tdep.c
+++ b/gdb/sparc-linux-tdep.c
@@ -96,7 +96,7 @@ sparc_linux_sigtramp_start (CORE_ADDR pc, ULONGEST insn0, ULONGEST insn1)
sequence, there will be a few trailing readable bytes on the
stack. */
- if (read_memory_nobpt (pc, buf, sizeof buf) != 0)
+ if (deprecated_read_memory_nobpt (pc, buf, sizeof buf) != 0)
return 0;
word0 = extract_unsigned_integer (buf, 4);
@@ -106,7 +106,7 @@ sparc_linux_sigtramp_start (CORE_ADDR pc, ULONGEST insn0, ULONGEST insn1)
return 0;
pc -= 4;
- if (read_memory_nobpt (pc, buf, sizeof buf) != 0)
+ if (deprecated_read_memory_nobpt (pc, buf, sizeof buf) != 0)
return 0;
word0 = extract_unsigned_integer (buf, 4);
diff --git a/gdb/frame.c b/gdb/frame.c
index c164d727369..dc65a4d8f07 100644
--- a/gdb/frame.c
+++ b/gdb/frame.c
@@ -2127,8 +2127,8 @@ int
safe_frame_unwind_memory (struct frame_info *this_frame,
CORE_ADDR addr, void *buf, int len)
{
- /* NOTE: read_memory_nobpt returns zero on success! */
- return !read_memory_nobpt (addr, buf, len);
+ /* NOTE: deprecated_read_memory_nobpt returns zero on success! */
+ return !deprecated_read_memory_nobpt (addr, buf, len);
}
/* Architecture method. */